OC.L10N.register(
    "settings",
    {
    "Authentication error" : "அத்தாட்சிப்படுத்தலில் வழு",
    "__language_name__" : "_மொழி_பெயர்_",
    "Language changed" : "மொழி மாற்றப்பட்டது",
    "Invalid request" : "செல்லுபடியற்ற வேண்டுகோள்",
    "All" : "எல்லாம்",
    "Disable" : "இயலுமைப்ப",
    "Enable" : "இயலுமைப்படுத்துக",
    "Delete" : "நீக்குக",
    "Groups" : "குழுக்கள்",
    "undo" : "முன் செயல் நீக்கம் ",
    "never" : "ஒருபோதும்",
    "None" : "ஒன்றுமில்லை",
    "Login" : "புகுபதிகை",
    "Encryption" : "மறைக்குறியீடு",
    "Server address" : "சேவையக முகவரி",
    "Port" : "துறை ",
    "Credentials" : "சான்று ஆவணங்கள்",
    "Cancel" : "இரத்து செய்க",
    "Email" : "மின்னஞ்சல்",
    "Your email address" : "உங்களுடைய மின்னஞ்சல் முகவரி",
    "Password" : "கடவுச்சொல்",
    "Unable to change your password" : "உங்களுடைய கடவுச்சொல்லை மாற்றமுடியாது",
    "Current password" : "தற்போதைய கடவுச்சொல்",
    "New password" : "புதிய கடவுச்சொல்",
    "Change password" : "கடவுச்சொல்லை மாற்றுக",
    "Language" : "மொழி",
    "Help translate" : "மொழிபெயர்க்க உதவி",
    "Name" : "பெயர்",
    "Username" : "பயனாளர் பெயர்",
    "Personal" : "தனிப்பட்ட",
    "Admin" : "நிர்வாகம்",
    "Error" : "வழு",
    "Create" : "உருவாக்குக",
    "Default Quota" : "பொது இருப்பு பங்கு",
    "Other" : "மற்றவை",
    "Quota" : "பங்கு",
    "Share" : "பகிர்வு",
    "Add" : "சேர்க்க"
},
"nplurals=2; plural=(n != 1);");
